=======
History
=======

0.1.5 (2017-06-25)
------------------

Added
~~~~~
* disabled option for schedules, to disable without deleting.

Fixes
~~~~~
* Don't replace other schedules unless this one is active.

0.1.5 (2017-06-25)
------------------

Added
~~~~~
* Support acting on list of lights or groups.
* Sending message to all lights asynchronously.
* One schedule can override another schedule.

0.1.4 (2017-06-24)
------------------

Fixes
~~~~~
* Add missing required depends.
* Handle Device Offline errors correctly.

0.1.3 (2017-06-24)
------------------

Added
~~~~~
* Schedule config file support.
* Requires my fork of aiolifx.

0.1.2 (2017-06-19)
------------------

Fixes
~~~~~
* PyPI meta information.
* day_of_week value incorrect.

0.1.1 (2017-06-18)
------------------

* No changes.

0.1.0 (2017-06-18)
------------------

* First release on PyPI.
